***********
RailProject
***********

==================
RailProject basics
==================

:py:class:`rail.projects.project.RailProject` is the main user facing class.

It collects all the elements needed to
run a collection of studies using RAIL.

.. autoclass:: rail.projects.RailProject
    :noindex:

       
==========================
Rail Project Functionality
==========================

.. automethod:: rail.projects.RailProject.functionality_help
    :noindex:
          
       
.. automethod:: rail.projects.RailProject.load_config 
    :noindex:

       
.. automethod:: rail.projects.RailProject.reduce_data
    :noindex:

       
.. automethod:: rail.projects.RailProject.subsample_data		
    :noindex:

       
.. automethod:: rail.projects.RailProject.subsample_data		
    :noindex:

       
.. automethod:: rail.projects.RailProject.build_pipelines		
    :noindex:

       
.. automethod:: rail.projects.RailProject.run_pipeline_single		
    :noindex:


.. automethod:: rail.projects.RailProject.run_pipeline_catalog
    :noindex:


==========================
Rail Project Configuration
==========================

.. automethod:: rail.projects.RailProject.configuration_help
    :noindex:
